Can search for information about releases on UPC and ISRC


Example:

# import
import deezapileaks

# we indicate in the variables isrc and upc
isrc = "XXXXXXXXXX"
upc = "XXXXXXXXXXX"

# print the result by isrc
print(deezapileaks.getisrc(isrc))
# print the result by upc
print(deezapileaks.getupc(upc))




